# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Model import IMainWindow

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Remoting

class Client(System.MarshalByRefObject, System.IDisposable):  # Class
    def __init__(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
        isWpf: bool,
    ) -> None: ...
    def GenerateTICLibrarySearchReport(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
    ) -> None: ...
    def AnalyzeSample(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
    ) -> None: ...
    def GenerateAreaPercentageReport(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
    ) -> None: ...
    def Debug(self) -> None: ...
    def Connect(self) -> None: ...
    def AnalyzeCompound(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
    ) -> None: ...
    def Dispose(self) -> None: ...

class Server(System.MarshalByRefObject, System.IDisposable):  # Class
    def __init__(self, mainWindow: IMainWindow) -> None: ...
    def SaveAnalysis(self) -> None: ...
    def NewAnalysis(self, batchFolder: str, analysisName: str) -> bool: ...
    def SetSampleProperties(
        self,
        parameters: Iterable[
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command.SampleColumnValuesParameter
        ],
    ) -> None: ...
    def RemoveLibraryMethod(self, batchID: int, sampleID: int) -> None: ...
    def Dispose(self) -> None: ...
    def Ready(self) -> None: ...
    def Register(self) -> None: ...
    def ImportQuantBatch(self, batchFolder: str, batchFileName: str) -> None: ...
    def SelectSamples(
        self,
        samples: List[
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.SampleRowID
        ],
    ) -> None: ...
    def SetMethods(
        self,
        batchID: int,
        sampleID: int,
        deconvolutionMethodValues: List[
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command.KeyValue
        ],
        identificationMethodvalues: List[
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command.KeyValue
        ],
        librarySearchMethodValues: List[
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command.KeyValue
        ],
    ) -> None: ...
    def Debug(self) -> None: ...
    def GetNewAnalysisName(self, batchFolder: str, baseName: str) -> str: ...
    def ImportQuantMethodFromBatch(
        self, batchFolder: str, batchFileName: str
    ) -> None: ...
    def AnalyzeSamples(
        self,
        samples: List[
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command.SampleRowIDParameter
        ],
    ) -> None: ...
    def SelectNearestComponent(self, rt: float) -> None: ...
    def SelectMatchedCompound(
        self, batchId: int, sampleId: int, compoundId: int
    ) -> bool: ...
    def AddSample(self, dataFileName: str) -> Optional[int]: ...
    def LoadMethodToAllSamples(self, methodPath: str) -> None: ...
    def Analyze(self) -> None: ...
    def SetAreaPercentColumnsVisible(self) -> None: ...
    def SetCulture(self, ci: System.Globalization.CultureInfo) -> None: ...



# -*- coding: utf-8 -*-
from __future__ import (
    absolute_import,
    division,
    generators,
    nested_scopes,
    print_function,
    unicode_literals,
    with_statement,
)

import datetime

from mh_operator.legacy.common import DataTableBase, RowBase, field_decorator


class LibraryRow(RowBase):
    """Represents a row for the Library table."""

    @field_decorator(index=0)
    def LibraryID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def AccurateMass(self):
        # type: () -> bool | None
        return self._values[1]

    @field_decorator(index=2)
    def CreationDateTime(self):
        # type: () -> datetime.datetime | None
        return self._values[2]

    @field_decorator(index=3)
    def Description(self):
        # type: () -> str | None
        return self._values[3]

    @field_decorator(index=4)
    def LastEditDateTime(self):
        # type: () -> datetime.datetime | None
        return self._values[4]

    @field_decorator(index=5)
    def LibraryName(self):
        # type: () -> str | None
        return self._values[5]

    @field_decorator(index=6)
    def LibrarySource(self):
        # type: () -> str | None
        return self._values[6]


class LibraryDataTable(DataTableBase[LibraryRow]):
    """Represents the Library table, containing LibraryRow objects."""

    pass


class CompoundRow(RowBase):
    """Represents a row for the Compound table."""

    @field_decorator(index=0)
    def LibraryID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def CompoundID(self):
        # type: () -> int | None
        return self._values[1]

    @field_decorator(index=2)
    def AlternateNames(self):
        # type: () -> str | None
        return self._values[2]

    @field_decorator(index=3)
    def BoilingPoint(self):
        # type: () -> float | None
        return self._values[3]

    @field_decorator(index=4)
    def CASNumber(self):
        # type: () -> str | None
        return self._values[4]

    @field_decorator(index=5)
    def CompoundName(self):
        # type: () -> str | None
        return self._values[5]

    @field_decorator(index=6)
    def Description(self):
        # type: () -> str | None
        return self._values[6]

    @field_decorator(index=7)
    def Formula(self):
        # type: () -> str | None
        return self._values[7]

    @field_decorator(index=8)
    def LastEditDateTime(self):
        # type: () -> datetime.datetime | None
        return self._values[8]

    @field_decorator(index=9)
    def MeltingPoint(self):
        # type: () -> float | None
        return self._values[9]

    @field_decorator(index=10)
    def MolecularWeight(self):
        # type: () -> float | None
        return self._values[10]

    @field_decorator(index=11)
    def MolFile(self):
        # type: () -> str | None
        return self._values[11]

    @field_decorator(index=12)
    def MonoisotopicMass(self):
        # type: () -> float | None
        return self._values[12]

    @field_decorator(index=13)
    def RetentionIndex(self):
        # type: () -> float | None
        return self._values[13]

    @field_decorator(index=14)
    def RetentionTimeRTL(self):
        # type: () -> float | None
        return self._values[14]

    @field_decorator(index=15)
    def UserDefined(self):
        # type: () -> str | None
        return self._values[15]


class CompoundDataTable(DataTableBase[CompoundRow]):
    """Represents the Compound table, containing CompoundRow objects."""

    pass


class SpectrumRow(RowBase):
    """Represents a row for the Spectrum table."""

    @field_decorator(index=0)
    def LibraryID(self):
        # type: () -> int | None
        return self._values[0]

    @field_decorator(index=1)
    def CompoundID(self):
        # type: () -> int | None
        return self._values[1]

    @field_decorator(index=2)
    def SpectrumID(self):
        # type: () -> int | None
        return self._values[2]

    @field_decorator(index=3)
    def AbundanceValues(self):
        # type: () -> str | None
        return self._values[3]

    @field_decorator(index=4)
    def AcqRetentionTime(self):
        # type: () -> float | None
        return self._values[4]

    @field_decorator(index=5)
    def BasePeakAbundance(self):
        # type: () -> float | None
        return self._values[5]

    @field_decorator(index=6)
    def BasePeakMZ(self):
        # type: () -> float | None
        return self._values[6]

    @field_decorator(index=7)
    def CollisionEnergy(self):
        # type: () -> float | None
        return self._values[7]

    @field_decorator(index=8)
    def HighestMz(self):
        # type: () -> float | None
        return self._values[8]

    @field_decorator(index=9)
    def IonizationEnergy(self):
        # type: () -> float | None
        return self._values[9]

    @field_decorator(index=10)
    def IonizationType(self):
        # type: () -> str | None
        return self._values[10]

    @field_decorator(index=11)
    def IonPolarity(self):
        # type: () -> str | None
        return self._values[11]

    @field_decorator(index=12)
    def InstrumentType(self):
        # type: () -> str | None
        return self._values[12]

    @field_decorator(index=13)
    def LastEditDateTime(self):
        # type: () -> datetime.datetime | None
        return self._values[13]

    @field_decorator(index=14)
    def LowestMz(self):
        # type: () -> float | None
        return self._values[14]

    @field_decorator(index=15)
    def MzSignature(self):
        # type: () -> str | None
        return self._values[15]

    @field_decorator(index=16)
    def MzSignatureBinWidth(self):
        # type: () -> float | None
        return self._values[16]

    @field_decorator(index=17)
    def MzValues(self):
        # type: () -> str | None
        return self._values[17]

    @field_decorator(index=18)
    def NumberOfPeaks(self):
        # type: () -> int | None
        return self._values[18]

    @field_decorator(index=19)
    def Origin(self):
        # type: () -> str | None
        return self._values[19]

    @field_decorator(index=20)
    def Owner(self):
        # type: () -> str | None
        return self._values[20]

    @field_decorator(index=21)
    def SampleID(self):
        # type: () -> str | None
        return self._values[21]

    @field_decorator(index=22)
    def ScanType(self):
        # type: () -> str | None
        return self._values[22]

    @field_decorator(index=23)
    def SelectedMZ(self):
        # type: () -> float | None
        return self._values[23]

    @field_decorator(index=24)
    def SeparationType(self):
        # type: () -> str | None
        return self._values[24]

    @field_decorator(index=25)
    def Species(self):
        # type: () -> str | None
        return self._values[25]

    @field_decorator(index=26)
    def UPlusAValues(self):
        # type: () -> str | None
        return self._values[26]

    @field_decorator(index=27)
    def UserDefined(self):
        # type: () -> str | None
        return self._values[27]


class SpectrumDataTable(DataTableBase[SpectrumRow]):
    """Represents the Spectrum table, containing SpectrumRow objects."""

    pass



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import OS, Controls, GlycanStructure

# Discovered Generic TypeVars:
TItem = TypeVar("TItem")
from . import IAtom, IBond, IMolecularStructure, Molecule
from .Controls import OpenFileDialogEx

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID

class Atom(
    IAtom, System.IEquatable[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Atom]
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self, orig: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Atom
    ) -> None: ...

    Alias: str
    AtomMappingNumber: int
    Attributes: Dict[
        str, Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomAttribute
    ]  # readonly
    Charge: int
    ChargeValue: int
    Coords: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomLocation
    ExactChangeFlag: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.ExactChangeOption
    )
    HODesignator: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.HODesignatorOption
    HydrogenCount: int
    Index: int
    InversionFlag: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.InversionOption
    IsotopeMass: int
    MassDifference: int
    Radical: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Radical
    StereoCareBox: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.StereoCareBoxOption
    )
    StereoParity: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.StereoParityType
    Symbol: str
    Valence: int

    def Equals(
        self, other: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Atom
    ) -> bool: ...
    def ToString(self) -> str: ...
    def Clone(self) -> Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Atom: ...

class AtomAttribute:  # Class
    @overload
    def __init__(
        self, orig: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomAttribute
    ) -> None: ...
    @overload
    def __init__(self, stringValue: str) -> None: ...
    @overload
    def __init__(self, intValue: int) -> None: ...
    @overload
    def __init__(self, doubleValue: float) -> None: ...
    @overload
    def __init__(self, objectValue: Any) -> None: ...

    DoubleValue: float
    IntValue: int
    ObjectValue: Any
    StringValue: str

    def Clone(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomAttribute: ...

class AtomCollection(
    Sequence[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Atom],
    System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Atom
    ],
    List[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Atom],
    Iterable[Any],
    Sequence[Any],
    Iterable[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Atom],
    List[Any],
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self, source: Iterable[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Atom]
    ) -> None: ...

    Center: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomLocation  # readonly

    def GetIndexForAtom(
        self, atom: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Atom
    ) -> int: ...

class AtomHighlightSet:  # Class
    def __init__(
        self,
        atoms: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomCollection,
        color: System.Drawing.Color,
    ) -> None: ...

    AtomCollection: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomCollection
    )  # readonly
    Color: System.Drawing.Color  # readonly

class AtomHighlightSets(
    Sequence[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomHighlightSet],
    List[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomHighlightSet],
    System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomHighlightSet
    ],
    Iterable[Any],
    Iterable[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomHighlightSet],
    Sequence[Any],
    List[Any],
):  # Class
    def __init__(self) -> None: ...
    def GetAtomColor(
        self,
        atom: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Atom,
        backgroundColor: System.Drawing.Color,
    ) -> System.Drawing.Color: ...

class AtomLocation:  # Class
    def __init__(self) -> None: ...

    X: float
    Y: float
    Z: float

class AtomTreeNode(
    System.IEquatable[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Atom],
    IAtom,
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Atom,
):  # Class
    def __init__(
        self, atom: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Atom
    ) -> None: ...
    def EnumSubTrees(
        self,
        listener: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.SubTreeListenerDelegate,
    ) -> None: ...
    @overload
    def AddChild(
        self, atom: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Atom
    ) -> Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomTreeNode: ...
    @overload
    def AddChild(
        self, atomNode: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomTreeNode
    ) -> Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomTreeNode: ...

class AtomTreeNodeCollection(
    System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomTreeNode
    ],
    Iterable[Any],
    List[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomTreeNode],
    Sequence[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomTreeNode],
    Iterable[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomTreeNode],
    List[Any],
    Sequence[Any],
):  # Class
    def __init__(self) -> None: ...

class AtomTreeNodeSet(
    Iterable[Any],
    Iterable[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomTreeNode],
    Sequence[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomTreeNode],
    Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Set[
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomTreeNode
    ],
):  # Class
    def __init__(self) -> None: ...

class Bond(
    IBond, System.IEquatable[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Bond]
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self, orig: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Bond
    ) -> None: ...
    @overload
    def __init__(self, indexAtom1: int, indexAtom2: int) -> None: ...

    IndexAtom1: int
    IndexAtom2: int
    Order: int  # readonly
    ReactingCenterStatus: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.ReactingCenterStatusOption
    )
    Stereo: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondStereo
    Topology: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondTopology
    Type: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondType

    def Equals(
        self, other: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Bond
    ) -> bool: ...
    def ToString(self) -> str: ...
    def Clone(self) -> Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Bond: ...

class BondCollection(
    System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Bond
    ],
    List[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Bond],
    Iterable[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Bond],
    Iterable[Any],
    Sequence[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Bond],
    Sequence[Any],
    List[Any],
):  # Class
    def __init__(self) -> None: ...

class BondHighlightSet:  # Class
    def __init__(
        self,
        bonds: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondCollection,
        color: System.Drawing.Color,
    ) -> None: ...

    BondCollection: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondCollection
    )  # readonly
    Color: System.Drawing.Color  # readonly

class BondHighlightSets(
    Iterable[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondHighlightSet],
    List[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondHighlightSet],
    System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondHighlightSet
    ],
    Iterable[Any],
    Sequence[Any],
    Sequence[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondHighlightSet],
    List[Any],
):  # Class
    def __init__(self) -> None: ...
    def GetBondColor(
        self, bond: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Bond
    ) -> System.Drawing.Color: ...

class BondStereo(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    CisOrTrans: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondStereo = (
        ...
    )  # static # readonly
    Down: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondStereo = (
        ...
    )  # static # readonly
    Either: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondStereo = (
        ...
    )  # static # readonly
    NotStereo: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondStereo = (
        ...
    )  # static # readonly
    Up: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondStereo = (
        ...
    )  # static # readonly

class BondTopology(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Chain: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondTopology = (
        ...
    )  # static # readonly
    Either: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondTopology = (
        ...
    )  # static # readonly
    Ring: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondTopology = (
        ...
    )  # static # readonly

class BondType(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    Any: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondType = (
        ...
    )  # static # readonly
    Aromatic: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondType = (
        ...
    )  # static # readonly
    Double: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondType = (
        ...
    )  # static # readonly
    DoubleOrAromatic: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondType = (
        ...
    )  # static # readonly
    Single: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondType = (
        ...
    )  # static # readonly
    SingleOrAromatic: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondType = (
        ...
    )  # static # readonly
    SingleOrDouble: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondType = (
        ...
    )  # static # readonly
    Triple: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.BondType = (
        ...
    )  # static # readonly

class ExactChangeOption(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    MustMatch: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.ExactChangeOption = (
        ...
    )  # static # readonly
    NotApplied: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.ExactChangeOption = (
        ...
    )  # static # readonly

class HODesignatorOption(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    NoHAtomsAllowed: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.HODesignatorOption
    ) = ...  # static # readonly
    NotSpecified: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.HODesignatorOption
    ) = ...  # static # readonly

class InversionOption(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Inverted: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.InversionOption = (
        ...
    )  # static # readonly
    NotApplied: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.InversionOption = (
        ...
    )  # static # readonly
    Retained: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.InversionOption = (
        ...
    )  # static # readonly

class MolFileReader:  # Class
    GlycoCTGlycanExtension: str = ...  # static # readonly
    KeggGlycanExtension: str = ...  # static # readonly
    LinucsGlycanExtension: str = ...  # static # readonly
    MOLExtension: str = ...  # static # readonly

    @staticmethod
    def ReadFromFile(
        path: str,
    ) -> Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.MolecularStructure: ...
    @overload
    @staticmethod
    def ReadFromStream(
        sr: System.IO.TextReader,
    ) -> Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.MolecularStructure: ...
    @overload
    @staticmethod
    def ReadFromStream(
        sr: System.IO.StreamReader,
    ) -> Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.MolecularStructure: ...

class MolFileWriter:  # Class
    @overload
    @staticmethod
    def WriteToStream(
        stream: System.IO.Stream,
        structure: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.MolecularStructure,
    ) -> None: ...
    @overload
    @staticmethod
    def WriteToStream(
        writer: System.IO.TextWriter,
        structure: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.MolecularStructure,
    ) -> None: ...
    @staticmethod
    def WriteToFile(
        path: str,
        structure: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.MolecularStructure,
    ) -> None: ...

class MolecularStructure(IMolecularStructure):  # Class
    Comment: str  # readonly
    DateAndTime: System.DateTime  # readonly
    DimCode: str  # readonly
    Energy: float  # readonly
    ExtendedProperties: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.StructurePropertyDictionary
    )  # readonly
    HasCharge: bool  # readonly
    IsValid: bool
    Molecule: Molecule  # readonly
    Name: str  # readonly
    ProgramName: str  # readonly
    RegistryNumber: int  # readonly
    ScalingFactor1: int  # readonly
    ScalingFactor2: float  # readonly
    TotalCharge: int  # readonly
    UserInitials: str  # readonly

    def ExportToFile(
        self,
        initialDirectory: str,
        proposedName: str,
        owner: System.Windows.Forms.IWin32Window,
    ) -> bool: ...

class MolecularStructureViewer(
    System.IDisposable,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.Control,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
):  # Class
    def __init__(self) -> None: ...

    BackColorEmpty: System.Drawing.Color
    FontScalingFactor: float
    LateralOffsetCutoffLength: float
    MaxFontSize: float
    MinFontSize: float
    ShowHAtoms: bool
    Structure: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.MolecularStructure

    def CopyToClipboard(self) -> None: ...
    def CopyToClipboardAdvanced(self) -> None: ...
    def DrawStructure(self, graphics: System.Drawing.Graphics) -> None: ...

class Radical(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    Doublet: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Radical = (
        ...
    )  # static # readonly
    NoRadical: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Radical = (
        ...
    )  # static # readonly
    Singlet: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Radical = (
        ...
    )  # static # readonly
    Triplet: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Radical = (
        ...
    )  # static # readonly

class ReactingCenterStatusOption(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    BondMadeOrBroken: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.ReactingCenterStatusOption
    ) = ...  # static # readonly
    BondMadeOrBrokenChanged: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.ReactingCenterStatusOption
    ) = ...  # static # readonly
    BondOrderChange: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.ReactingCenterStatusOption
    ) = ...  # static # readonly
    Center: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.ReactingCenterStatusOption
    ) = ...  # static # readonly
    CenterOrBondMadeOrBroken: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.ReactingCenterStatusOption
    ) = ...  # static # readonly
    CenterOrBondMadeOrBrokenChanged: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.ReactingCenterStatusOption
    ) = ...  # static # readonly
    CenterOrBondOrderChange: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.ReactingCenterStatusOption
    ) = ...  # static # readonly
    NoChange: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.ReactingCenterStatusOption
    ) = ...  # static # readonly
    NotACenter: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.ReactingCenterStatusOption
    ) = ...  # static # readonly
    Unmarked: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.ReactingCenterStatusOption
    ) = ...  # static # readonly

class SDFFileReader:  # Class
    SDFExtension: str = ...  # static # readonly

    @overload
    @staticmethod
    def ReadFromFile(
        path: str,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.MolecularStructure
    ]: ...
    @overload
    @staticmethod
    def ReadFromFile(
        path: str, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.MolecularStructure: ...
    @overload
    @staticmethod
    def ReadFromStream(
        sr: System.IO.TextReader,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.MolecularStructure
    ]: ...
    @overload
    @staticmethod
    def ReadFromStream(
        sr: System.IO.StreamReader, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.MolecularStructure: ...

class SDFFileWriter:  # Class
    @overload
    @staticmethod
    def WriteToStream(
        stream: System.IO.Stream,
        structures: List[
            Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.MolecularStructure
        ],
    ) -> None: ...
    @overload
    @staticmethod
    def WriteToStream(
        writer: System.IO.TextWriter,
        structures: List[
            Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.MolecularStructure
        ],
    ) -> None: ...
    @overload
    @staticmethod
    def WriteToStream(
        stream: System.IO.Stream,
        structures: List[
            Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.MolecularStructure
        ],
        indices: List[int],
    ) -> None: ...
    @overload
    @staticmethod
    def WriteToStream(
        writer: System.IO.TextWriter,
        structures: List[
            Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.MolecularStructure
        ],
        indices: List[int],
    ) -> None: ...
    @overload
    @staticmethod
    def WriteToFile(
        path: str,
        structures: List[
            Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.MolecularStructure
        ],
    ) -> None: ...
    @overload
    @staticmethod
    def WriteToFile(
        path: str,
        structures: List[
            Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.MolecularStructure
        ],
        indices: List[int],
    ) -> None: ...

class Set(Generic[TItem], Iterable[Any], Iterable[TItem], Sequence[TItem]):  # Class
    def __init__(self) -> None: ...

    Count: int  # readonly
    IsReadOnly: bool  # readonly

    def AsReadOnly(self) -> Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Set: ...
    def Contains(self, item: TItem) -> bool: ...
    def CopyTo(self, array: List[TItem], arrayIndex: int) -> None: ...
    def GetEnumerator(self) -> Iterator[TItem]: ...
    def Add(self, item: TItem) -> None: ...
    def Clear(self) -> None: ...
    def Remove(self, item: TItem) -> bool: ...

class StereoCareBoxOption(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Ignore: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.StereoCareBoxOption = (
        ...
    )  # static # readonly
    MustMatch: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.StereoCareBoxOption
    ) = ...  # static # readonly

class StereoParityType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Even: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.StereoParityType = (
        ...
    )  # static # readonly
    NotStereo: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.StereoParityType = (
        ...
    )  # static # readonly
    Odd: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.StereoParityType = (
        ...
    )  # static # readonly
    Unmarked: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.StereoParityType = (
        ...
    )  # static # readonly

class StructureFieldInfo:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, fieldName: str) -> None: ...

    ExternalRegistry: str
    InternalRegistry: str
    Name: str
    Number: int

    def GetHashCode(self) -> int: ...
    def Equals(self, obj: Any) -> bool: ...

class StructureOpenFileDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    OpenFileDialogEx,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    StructureIndex: int  # readonly

    def OnFileNameChanged(self, filePath: str) -> None: ...
    def OnClosingDialog(self) -> None: ...
    def OnFolderNameChanged(self, folderName: str) -> None: ...

class StructurePropertyDictionary(
    Mapping[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.StructureFieldInfo, str],
    Iterable[Any],
    Dict[Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.StructureFieldInfo, str],
    System.Runtime.Serialization.IDeserializationCallback,
    Sequence[Any],
    System.Runtime.Serialization.ISerializable,
    Dict[Any, Any],
    Sequence[
        System.Collections.Generic.KeyValuePair[
            Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.StructureFieldInfo, str
        ]
    ],
    Iterable[
        System.Collections.Generic.KeyValuePair[
            Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.StructureFieldInfo, str
        ]
    ],
):  # Class
    def __init__(self) -> None: ...
    def __getitem__(self, fieldname: str) -> str: ...

class SubTreeListenerDelegate(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        root: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomTreeNode,
        leaves: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomTreeNodeSet,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(
        self,
        root: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomTreeNode,
        leaves: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.AtomTreeNodeSet,
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.SecureFileSystem

class LsaUtility:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def SetRight(accountName: str, privilegeName: str) -> int: ...
    @staticmethod
    def FreeSid(pSid: System.IntPtr) -> None: ...

class PasswordUtility:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def EncryptPassword(password: str) -> str: ...
    @staticmethod
    def DecryptPassword(encrypted: str) -> System.Security.SecureString: ...

class SecureFolder:  # Class
    def __init__(self) -> None: ...

    CustomerHome: str  # static # readonly

    @staticmethod
    def GetSecureFolder(rootFolder: str) -> str: ...
    @staticmethod
    def GetUserFolder(rootFolder: str) -> str: ...
    @staticmethod
    def SetupFolders(userName: str, domainName: str, rootFolder: str) -> None: ...
    @staticmethod
    def GetCacheFolder(rootFolder: str) -> str: ...

class UserUtilities:  # Class
    def __init__(self) -> None: ...

    DefaultDomainName: str = ...  # static # readonly
    DefaultSecureUserName: str = ...  # static # readonly

    @staticmethod
    def SaveUserInfo(
        userName: str,
        domainName: str,
        password: System.Security.SecureString,
        file: str,
    ) -> None: ...
    @staticmethod
    def DecryptSecure(cipher: str) -> System.Security.SecureString: ...
    @staticmethod
    def Encrypt(value_: System.Security.SecureString) -> str: ...
    @staticmethod
    def CreateNewUser(
        userName: str, password: System.Security.SecureString, description: str
    ) -> None: ...
    @staticmethod
    def LoadUserInfo(
        file: str,
        userName: str,
        domainName: str,
        password: System.Security.SecureString,
    ) -> None: ...
    @staticmethod
    def GetUserFileInfoPath(rootFolder: str) -> str: ...
    @staticmethod
    def GenerateNewPassword(
        minLength: int,
        minUppercase: int,
        minLowercase: int,
        minDigits: int,
        minNonAlphanumeric: int,
    ) -> System.Security.SecureString: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Engine
from .Template import IColor, IFont, ILength, ILine

# Stubs for namespace: Agilent.MassHunter.ReportBuilder.Common

class ColorComparer(System.Collections.Generic.IEqualityComparer[IColor]):  # Class
    def __init__(self) -> None: ...
    def GetHashCode(self, obj: IColor) -> int: ...
    def Equals(self, x: IColor, y: IColor) -> bool: ...

class FontComparer(System.Collections.Generic.IEqualityComparer[IFont]):  # Class
    def __init__(self) -> None: ...
    def GetHashCode(self, obj: IFont) -> int: ...
    def Equals(self, x: IFont, y: IFont) -> bool: ...

class LengthComparer(System.Collections.Generic.IEqualityComparer[ILength]):  # Class
    def __init__(self) -> None: ...
    def GetHashCode(self, obj: ILength) -> int: ...
    def Equals(self, x: ILength, y: ILength) -> bool: ...

class LineComparer(System.Collections.Generic.IEqualityComparer[ILine]):  # Class
    def __init__(self) -> None: ...
    def GetHashCode(self, obj: ILine) -> int: ...
    def Equals(self, x: ILine, y: ILine) -> bool: ...

class ReportBuilderAbortException(
    System.Runtime.InteropServices._Exception,
    Agilent.MassHunter.ReportBuilder.Common.ReportBuilderException,
    System.Runtime.Serialization.ISerializable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...

class ReportBuilderException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...
    @overload
    def __init__(
        self,
        info: System.Runtime.Serialization.SerializationInfo,
        context: System.Runtime.Serialization.StreamingContext,
    ) -> None: ...

class ReportBuilderPreviewAbortException(
    System.Runtime.InteropServices._Exception,
    Agilent.MassHunter.ReportBuilder.Common.ReportBuilderException,
    System.Runtime.Serialization.ISerializable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...
    @overload
    def __init__(
        self,
        info: System.Runtime.Serialization.SerializationInfo,
        context: System.Runtime.Serialization.StreamingContext,
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: System.Data.SqlServerCe

class AddOption(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    CreateDatabase: System.Data.SqlServerCe.AddOption = ...  # static # readonly
    ExistingDatabase: System.Data.SqlServerCe.AddOption = ...  # static # readonly

class CommitMode(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Deferred: System.Data.SqlServerCe.CommitMode = ...  # static # readonly
    Immediate: System.Data.SqlServerCe.CommitMode = ...  # static # readonly

class DbInsertOptions(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    KeepCurrentPosition: System.Data.SqlServerCe.DbInsertOptions = (
        ...
    )  # static # readonly
    PositionOnInsertedRow: System.Data.SqlServerCe.DbInsertOptions = (
        ...
    )  # static # readonly

class DbRangeOptions(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Default: System.Data.SqlServerCe.DbRangeOptions = ...  # static # readonly
    ExcludeNulls: System.Data.SqlServerCe.DbRangeOptions = ...  # static # readonly
    ExclusiveEnd: System.Data.SqlServerCe.DbRangeOptions = ...  # static # readonly
    ExclusiveStart: System.Data.SqlServerCe.DbRangeOptions = ...  # static # readonly
    InclusiveEnd: System.Data.SqlServerCe.DbRangeOptions = ...  # static # readonly
    InclusiveStart: System.Data.SqlServerCe.DbRangeOptions = ...  # static # readonly
    Match: System.Data.SqlServerCe.DbRangeOptions = ...  # static # readonly
    Prefix: System.Data.SqlServerCe.DbRangeOptions = ...  # static # readonly

class DbSeekOptions(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    After: System.Data.SqlServerCe.DbSeekOptions = ...  # static # readonly
    AfterEqual: System.Data.SqlServerCe.DbSeekOptions = ...  # static # readonly
    Before: System.Data.SqlServerCe.DbSeekOptions = ...  # static # readonly
    BeforeEqual: System.Data.SqlServerCe.DbSeekOptions = ...  # static # readonly
    FirstEqual: System.Data.SqlServerCe.DbSeekOptions = ...  # static # readonly
    LastEqual: System.Data.SqlServerCe.DbSeekOptions = ...  # static # readonly

class DropOption(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    DropDatabase: System.Data.SqlServerCe.DropOption = ...  # static # readonly
    LeaveDatabase: System.Data.SqlServerCe.DropOption = ...  # static # readonly
    UnregisterSubscription: System.Data.SqlServerCe.DropOption = (
        ...
    )  # static # readonly

class ExchangeType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    BiDirectional: System.Data.SqlServerCe.ExchangeType = ...  # static # readonly
    Upload: System.Data.SqlServerCe.ExchangeType = ...  # static # readonly

class NetworkType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    DefaultNetwork: System.Data.SqlServerCe.NetworkType = ...  # static # readonly
    MultiProtocol: System.Data.SqlServerCe.NetworkType = ...  # static # readonly
    TcpIpSockets: System.Data.SqlServerCe.NetworkType = ...  # static # readonly

class OnStartTableDownload(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        ar: System.IAsyncResult,
        tableName: str,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, ar: System.IAsyncResult, tableName: str) -> None: ...

class OnStartTableUpload(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        ar: System.IAsyncResult,
        tableName: str,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, ar: System.IAsyncResult, tableName: str) -> None: ...

class OnSynchronization(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        ar: System.IAsyncResult,
        percentComplete: int,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, ar: System.IAsyncResult, percentComplete: int) -> None: ...

class PurgeType(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    CsnBased: System.Data.SqlServerCe.PurgeType = ...  # static # readonly
    Max: System.Data.SqlServerCe.PurgeType = ...  # static # readonly
    TimeBased: System.Data.SqlServerCe.PurgeType = ...  # static # readonly

class RdaBatchOption(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    BatchingOff: System.Data.SqlServerCe.RdaBatchOption = ...  # static # readonly
    BatchingOn: System.Data.SqlServerCe.RdaBatchOption = ...  # static # readonly

class RdaTrackOption(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    TrackingOff: System.Data.SqlServerCe.RdaTrackOption = ...  # static # readonly
    TrackingOffWithIndexes: System.Data.SqlServerCe.RdaTrackOption = (
        ...
    )  # static # readonly
    TrackingOn: System.Data.SqlServerCe.RdaTrackOption = ...  # static # readonly
    TrackingOnWithIndexes: System.Data.SqlServerCe.RdaTrackOption = (
        ...
    )  # static # readonly

class RepairOption(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    DeleteCorruptedRows: System.Data.SqlServerCe.RepairOption = ...  # static # readonly
    RecoverAllOrFail: System.Data.SqlServerCe.RepairOption = ...  # static # readonly
    RecoverAllPossibleRows: System.Data.SqlServerCe.RepairOption = (
        ...
    )  # static # readonly
    RecoverCorruptedRows: System.Data.SqlServerCe.RepairOption = (
        ...
    )  # static # readonly

class ResultSetEnumerator(Iterator[Any]):  # Class
    def __init__(self, resultSet: System.Data.SqlServerCe.SqlCeResultSet) -> None: ...

    Current: System.Data.SqlServerCe.SqlCeUpdatableRecord  # readonly

    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...

class ResultSetOptions(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Insensitive: System.Data.SqlServerCe.ResultSetOptions = ...  # static # readonly
    Scrollable: System.Data.SqlServerCe.ResultSetOptions = ...  # static # readonly
    Sensitive: System.Data.SqlServerCe.ResultSetOptions = ...  # static # readonly
    Updatable: System.Data.SqlServerCe.ResultSetOptions = ...  # static # readonly

class ResultSetSensitivity(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Asensitive: System.Data.SqlServerCe.ResultSetSensitivity = ...  # static # readonly
    Insensitive: System.Data.SqlServerCe.ResultSetSensitivity = ...  # static # readonly
    Sensitive: System.Data.SqlServerCe.ResultSetSensitivity = ...  # static # readonly

class ResultSetView(
    Iterable[Any],
    List[Any],
    System.ComponentModel.IBindingList,
    System.IDisposable,
    System.ComponentModel.ITypedList,
    Sequence[Any],
):  # Class
    Columns: List[str]
    Ordinals: List[int]

    ListChanged: System.ComponentModel.ListChangedEventHandler  # Event

class RowView(
    System.ComponentModel.IDataErrorInfo,
    System.ComponentModel.IEditableObject,
    System.IDisposable,
):  # Class
    UpdatableRecord: System.Data.SqlServerCe.SqlCeUpdatableRecord  # readonly

    def GetHashCode(self) -> int: ...
    def Dispose(self) -> None: ...
    def Equals(self, other: Any) -> bool: ...

class SecurityType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    DBAuthentication: System.Data.SqlServerCe.SecurityType = ...  # static # readonly
    NTAuthentication: System.Data.SqlServerCe.SecurityType = ...  # static # readonly

class SnapshotTransferType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    FTP: System.Data.SqlServerCe.SnapshotTransferType = ...  # static # readonly
    UNC: System.Data.SqlServerCe.SnapshotTransferType = ...  # static # readonly

class SqlCeChangeTracking(System.IDisposable):  # Class
    @overload
    def __init__(
        self, transaction: System.Data.SqlServerCe.SqlCeTransaction
    ) -> None: ...
    @overload
    def __init__(self, connection: System.Data.SqlServerCe.SqlCeConnection) -> None: ...
    def PurgeTombstoneTableData(
        self,
        tableName: str,
        pType: System.Data.SqlServerCe.PurgeType,
        retentionValue: int,
    ) -> None: ...
    def EnableTracking(
        self,
        tableName: str,
        trackingKeyType: System.Data.SqlServerCe.TrackingKeyType,
        trackingOptions: System.Data.SqlServerCe.TrackingOptions,
    ) -> None: ...
    @staticmethod
    def UpgradePublicTracking(connectionString: str) -> bool: ...
    def PurgeTransactionSequenceData(
        self, pType: System.Data.SqlServerCe.PurgeType, retentionValue: int
    ) -> None: ...
    def DisableTracking(self, tableName: str) -> None: ...
    @overload
    def Dispose(self) -> None: ...
    @overload
    def Dispose(self, disposing: bool) -> None: ...
    def PackTombstoneKey(
        self, tableName: str, columnValues: List[Any]
    ) -> List[int]: ...
    def GetTrackingOptions(
        self, tableName: str, trackingOptions: System.Data.SqlServerCe.TrackingOptions
    ) -> bool: ...
    def GetLastCommittedCsn(self) -> int: ...
    def UnpackTombstoneKey(
        self, tableName: str, tombstoneKey: List[int]
    ) -> List[Any]: ...

class SqlCeCommand(
    System.Data.IDbCommand,
    System.IDisposable,
    System.Data.Common.DbCommand,
    System.ComponentModel.IComponent,
    System.ICloneable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, commandText: str) -> None: ...
    @overload
    def __init__(
        self, commandText: str, connection: System.Data.SqlServerCe.SqlCeConnection
    ) -> None: ...
    @overload
    def __init__(
        self,
        commandText: str,
        connection: System.Data.SqlServerCe.SqlCeConnection,
        transaction: System.Data.SqlServerCe.SqlCeTransaction,
    ) -> None: ...

    CommandText: str
    CommandTimeout: int
    CommandType: System.Data.CommandType
    Connection: System.Data.SqlServerCe.SqlCeConnection
    DesignTimeVisible: bool
    IndexName: str
    Parameters: System.Data.SqlServerCe.SqlCeParameterCollection  # readonly
    Transaction: System.Data.SqlServerCe.SqlCeTransaction
    UpdatedRowSource: System.Data.UpdateRowSource

    def CreateParameter(self) -> System.Data.SqlServerCe.SqlCeParameter: ...
    def ExecuteScalar(self) -> Any: ...
    @overload
    def ExecuteReader(self) -> System.Data.SqlServerCe.SqlCeDataReader: ...
    @overload
    def ExecuteReader(
        self, behavior: System.Data.CommandBehavior
    ) -> System.Data.SqlServerCe.SqlCeDataReader: ...
    def SetRange(
        self,
        dbRangeOptions: System.Data.SqlServerCe.DbRangeOptions,
        startData: List[Any],
        endData: List[Any],
    ) -> None: ...
    def Prepare(self) -> None: ...
    def ExecuteNonQuery(self) -> int: ...
    @overload
    def ExecuteResultSet(
        self, options: System.Data.SqlServerCe.ResultSetOptions
    ) -> System.Data.SqlServerCe.SqlCeResultSet: ...
    @overload
    def ExecuteResultSet(
        self,
        options: System.Data.SqlServerCe.ResultSetOptions,
        resultSet: System.Data.SqlServerCe.SqlCeResultSet,
    ) -> System.Data.SqlServerCe.SqlCeResultSet: ...
    def Cancel(self) -> None: ...

class SqlCeCommandBuilder(
    System.Data.Common.DbCommandBuilder,
    System.IDisposable,
    System.ComponentModel.IComponent,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, adapter: System.Data.SqlServerCe.SqlCeDataAdapter) -> None: ...

    CatalogLocation: System.Data.Common.CatalogLocation
    CatalogSeparator: str
    ConflictOption: System.Data.ConflictOption
    DataAdapter: System.Data.SqlServerCe.SqlCeDataAdapter
    QuotePrefix: str
    QuoteSuffix: str
    SchemaSeparator: str

    def UnquoteIdentifier(self, quotedIdentifier: str) -> str: ...
    def GetUpdateCommand(self) -> System.Data.SqlServerCe.SqlCeCommand: ...
    def GetInsertCommand(self) -> System.Data.SqlServerCe.SqlCeCommand: ...
    def GetDeleteCommand(self) -> System.Data.SqlServerCe.SqlCeCommand: ...
    def QuoteIdentifier(self, unquotedIdentifier: str) -> str: ...

class SqlCeConnection(
    System.IDisposable,
    System.Data.Common.DbConnection,
    System.Data.IDbConnection,
    System.ComponentModel.IComponent,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, connectionString: str) -> None: ...

    ConnectionString: str
    ConnectionTimeout: int  # readonly
    DataSource: str  # readonly
    Database: str  # readonly
    DatabaseIdentifier: str  # readonly
    ServerVersion: str  # readonly
    State: System.Data.ConnectionState  # readonly

    def Open(self) -> None: ...
    @overload
    def GetSchema(self) -> System.Data.DataTable: ...
    @overload
    def GetSchema(self, collectionName: str) -> System.Data.DataTable: ...
    @overload
    def GetSchema(
        self, collectionName: str, restrictionValues: List[str]
    ) -> System.Data.DataTable: ...
    def Close(self) -> None: ...
    def CreateCommand(self) -> System.Data.SqlServerCe.SqlCeCommand: ...
    @overload
    def BeginTransaction(
        self, isolationLevel: System.Data.IsolationLevel
    ) -> System.Data.SqlServerCe.SqlCeTransaction: ...
    @overload
    def BeginTransaction(self) -> System.Data.SqlServerCe.SqlCeTransaction: ...
    def Dispose(self) -> None: ...
    def EnlistTransaction(self, SysTrans: System.Transactions.Transaction) -> None: ...
    def GetDatabaseInfo(
        self,
    ) -> System.Collections.Generic.List[
        System.Collections.Generic.KeyValuePair[str, str]
    ]: ...
    def ChangeDatabase(self, value_: str) -> None: ...

    FlushFailure: System.Data.SqlServerCe.SqlCeFlushFailureEventHandler  # Event
    InfoMessage: System.Data.SqlServerCe.SqlCeInfoMessageEventHandler  # Event
    StateChange: System.Data.StateChangeEventHandler  # Event

class SqlCeConnectionStringBuilder(
    System.Data.Common.DbConnectionStringBuilder,
    Dict[Any, Any],
    Iterable[Any],
    Sequence[Any],
    System.ComponentModel.ICustomTypeDescriptor,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, connectionString: str) -> None: ...

    AutoshrinkThreshold: int
    CaseSensitive: bool
    DataSource: str
    DefaultLockEscalation: int
    DefaultLockTimeout: int
    Encrypt: bool
    EncryptionMode: str
    Enlist: bool
    FileMode: str
    FlushInterval: int
    InitialLcid: int
    IsFixedSize: bool  # readonly
    def __getitem__(self, keyword: str) -> Any: ...
    def __setitem__(self, keyword: str, value_: Any) -> None: ...
    Keys: Sequence[Any]  # readonly
    MaxBufferSize: int
    MaxDatabaseSize: int
    Password: str
    PersistSecurityInfo: bool
    TempFileMaxSize: int
    TempFilePath: str
    Values: Sequence[Any]  # readonly

    def ShouldSerialize(self, keyword: str) -> bool: ...
    def ContainsKey(self, keyword: str) -> bool: ...
    def Clear(self) -> None: ...
    def TryGetValue(self, keyword: str, value_: Any) -> bool: ...
    def Remove(self, keyword: str) -> bool: ...

class SqlCeDataAdapter(
    System.Data.Common.DbDataAdapter,
    System.Data.IDbDataAdapter,
    System.Data.IDataAdapter,
    System.IDisposable,
    System.ICloneable,
    System.ComponentModel.IComponent,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, selectCommand: System.Data.SqlServerCe.SqlCeCommand) -> None: ...
    @overload
    def __init__(self, selectCommandText: str, selectConnectionString: str) -> None: ...
    @overload
    def __init__(
        self,
        selectCommandText: str,
        selectConnection: System.Data.SqlServerCe.SqlCeConnection,
    ) -> None: ...

    DeleteCommand: System.Data.SqlServerCe.SqlCeCommand
    InsertCommand: System.Data.SqlServerCe.SqlCeCommand
    SelectCommand: System.Data.SqlServerCe.SqlCeCommand
    UpdateCommand: System.Data.SqlServerCe.SqlCeCommand

    def Dispose(self) -> None: ...

    RowUpdated: System.Data.SqlServerCe.SqlCeRowUpdatedEventHandler  # Event
    RowUpdating: System.Data.SqlServerCe.SqlCeRowUpdatingEventHandler  # Event

class SqlCeDataReader(
    System.Data.IDataReader,
    System.Data.IDataRecord,
    System.IDisposable,
    Iterable[Any],
    System.Data.Common.DbDataReader,
):  # Class
    Depth: int  # readonly
    FieldCount: int  # readonly
    HasRows: bool  # readonly
    HiddenFieldCount: int  # readonly
    IsClosed: bool  # readonly
    def __getitem__(self, index: int) -> Any: ...
    def __getitem__(self, name: str) -> Any: ...
    RecordsAffected: int  # readonly

    def GetSqlInt32(self, ordinal: int) -> System.Data.SqlTypes.SqlInt32: ...
    def GetString(self, ordinal: int) -> str: ...
    def GetSqlDouble(self, ordinal: int) -> System.Data.SqlTypes.SqlDouble: ...
    def GetName(self, index: int) -> str: ...
    def GetDateTime(self, ordinal: int) -> System.DateTime: ...
    def GetSqlBinary(self, ordinal: int) -> System.Data.SqlTypes.SqlBinary: ...
    def GetSchemaTable(self) -> System.Data.DataTable: ...
    def GetSqlSingle(self, ordinal: int) -> System.Data.SqlTypes.SqlSingle: ...
    def GetSqlInt64(self, ordinal: int) -> System.Data.SqlTypes.SqlInt64: ...
    def GetOrdinal(self, name: str) -> int: ...
    def GetChars(
        self,
        ordinal: int,
        dataIndex: int,
        buffer: List[str],
        bufferIndex: int,
        length: int,
    ) -> int: ...
    def Dispose(self) -> None: ...
    def GetSqlDecimal(self, ordinal: int) -> System.Data.SqlTypes.SqlDecimal: ...
    def GetInt32(self, ordinal: int) -> int: ...
    def GetByte(self, ordinal: int) -> int: ...
    def GetDecimal(self, ordinal: int) -> System.Decimal: ...
    def GetSqlMoney(self, ordinal: int) -> System.Data.SqlTypes.SqlMoney: ...
    def Read(self) -> bool: ...
    def IsDBNull(self, ordinal: int) -> bool: ...
    def GetGuid(self, ordinal: int) -> System.Guid: ...
    def GetBoolean(self, ordinal: int) -> bool: ...
    def GetSqlGuid(self, ordinal: int) -> System.Data.SqlTypes.SqlGuid: ...
    def GetSqlDateTime(self, ordinal: int) -> System.Data.SqlTypes.SqlDateTime: ...
    def GetDouble(self, ordinal: int) -> float: ...
    def NextResult(self) -> bool: ...
    def Close(self) -> None: ...
    def GetSqlBoolean(self, ordinal: int) -> System.Data.SqlTypes.SqlBoolean: ...
    def GetInt64(self, ordinal: int) -> int: ...
    def GetChar(self, ordinal: int) -> str: ...
    def GetSqlByte(self, ordinal: int) -> System.Data.SqlTypes.SqlByte: ...
    def GetProviderSpecificFieldType(self, ordinal: int) -> System.Type: ...
    def GetValues(self, values: List[Any]) -> int: ...
    def GetSqlInt16(self, ordinal: int) -> System.Data.SqlTypes.SqlInt16: ...
    def GetBytes(
        self,
        ordinal: int,
        dataIndex: int,
        buffer: List[int],
        bufferIndex: int,
        length: int,
    ) -> int: ...
    def GetDataTypeName(self, index: int) -> str: ...
    def GetEnumerator(self) -> Iterator[Any]: ...
    def GetInt16(self, ordinal: int) -> int: ...
    def GetFloat(self, ordinal: int) -> float: ...
    def Seek(
        self, dbSeekOptions: System.Data.SqlServerCe.DbSeekOptions, index: List[Any]
    ) -> bool: ...
    def GetFieldType(self, ordinal: int) -> System.Type: ...
    def GetSqlString(self, ordinal: int) -> System.Data.SqlTypes.SqlString: ...
    def GetValue(self, ordinal: int) -> Any: ...

class SqlCeEngine(System.IDisposable):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, connectionString: str) -> None: ...

    LocalConnectionString: str

    def Repair(
        self, connectionString: str, options: System.Data.SqlServerCe.RepairOption
    ) -> None: ...
    def Compact(self, connectionString: str) -> None: ...
    def Shrink(self) -> None: ...
    def CreateDatabase(self) -> None: ...
    @overload
    def Verify(self) -> bool: ...
    @overload
    def Verify(self, option: System.Data.SqlServerCe.VerifyOption) -> bool: ...
    @overload
    def Upgrade(self) -> None: ...
    @overload
    def Upgrade(self, destConnectionString: str) -> None: ...
    def Dispose(self) -> None: ...

class SqlCeError:  # Class
    ErrorParameters: List[str]  # readonly
    HResult: int  # readonly
    Message: str  # readonly
    NativeError: int  # readonly
    NumericErrorParameters: List[int]  # readonly
    Source: str  # readonly

    def ToString(self) -> str: ...

class SqlCeErrorCollection(Iterable[Any], Sequence[Any]):  # Class
    Count: int  # readonly
    def __getitem__(self, index: int) -> System.Data.SqlServerCe.SqlCeError: ...
    def GetEnumerator(self) -> Iterator[Any]: ...
    def CopyTo(self, array: System.Array, index: int) -> None: ...

class SqlCeException(
    System.Runtime.InteropServices._Exception,
    System.Data.Common.DbException,
    System.Runtime.Serialization.ISerializable,
):  # Class
    Errors: System.Data.SqlServerCe.SqlCeErrorCollection  # readonly
    HResult: int  # readonly
    Message: str  # readonly
    NativeError: int  # readonly
    Source: str  # readonly

    def GetObjectData(
        self,
        info: System.Runtime.Serialization.SerializationInfo,
        context: System.Runtime.Serialization.StreamingContext,
    ) -> None: ...

class SqlCeFlushFailureEventArgs(System.EventArgs):  # Class
    Errors: System.Data.SqlServerCe.SqlCeErrorCollection  # readonly
    Message: str  # readonly

    def ToString(self) -> str: ...

class SqlCeFlushFailureEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        e: System.Data.SqlServerCe.SqlCeFlushFailureEventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(
        self, sender: Any, e: System.Data.SqlServerCe.SqlCeFlushFailureEventArgs
    ) -> None: ...

class SqlCeInfoMessageEventArgs(System.EventArgs):  # Class
    Errors: System.Data.SqlServerCe.SqlCeErrorCollection  # readonly
    Message: str  # readonly

    def ToString(self) -> str: ...

class SqlCeInfoMessageEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        e: System.Data.SqlServerCe.SqlCeInfoMessageEventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(
        self, sender: Any, e: System.Data.SqlServerCe.SqlCeInfoMessageEventArgs
    ) -> None: ...

class SqlCeInvalidDatabaseFormatException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Data.SqlServerCe.SqlCeException,
):  # Class
    def GetObjectData(
        self,
        info: System.Runtime.Serialization.SerializationInfo,
        context: System.Runtime.Serialization.StreamingContext,
    ) -> None: ...

class SqlCeLockTimeoutException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Data.SqlServerCe.SqlCeException,
):  # Class
    def GetObjectData(
        self,
        info: System.Runtime.Serialization.SerializationInfo,
        context: System.Runtime.Serialization.StreamingContext,
    ) -> None: ...

class SqlCeParameter(
    System.ICloneable,
    System.Data.IDataParameter,
    System.Data.IDbDataParameter,
    System.Data.Common.DbParameter,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str, value_: Any) -> None: ...
    @overload
    def __init__(self, name: str, dataType: System.Data.SqlDbType) -> None: ...
    @overload
    def __init__(
        self, name: str, dataType: System.Data.SqlDbType, size: int
    ) -> None: ...
    @overload
    def __init__(
        self, name: str, dataType: System.Data.SqlDbType, size: int, sourceColumn: str
    ) -> None: ...
    @overload
    def __init__(
        self,
        parameterName: str,
        dbType: System.Data.SqlDbType,
        size: int,
        isNullable: bool,
        precision: int,
        scale: int,
        sourceColumn: str,
        sourceVersion: System.Data.DataRowVersion,
        value_: Any,
    ) -> None: ...
    @overload
    def __init__(
        self,
        parameterName: str,
        dbType: System.Data.SqlDbType,
        size: int,
        direction: System.Data.ParameterDirection,
        isNullable: bool,
        precision: int,
        scale: int,
        sourceColumn: str,
        sourceVersion: System.Data.DataRowVersion,
        value_: Any,
    ) -> None: ...

    DbType: System.Data.DbType
    Direction: System.Data.ParameterDirection
    IsNullable: bool
    Offset: int
    ParameterName: str
    Precision: int
    Scale: int
    Size: int
    SourceColumn: str
    SourceColumnNullMapping: bool
    SourceVersion: System.Data.DataRowVersion
    SqlDbType: System.Data.SqlDbType
    Value: Any

    def ResetDbType(self) -> None: ...
    def ToString(self) -> str: ...

class SqlCeParameterCollection(
    List[Any],
    System.Data.IDataParameterCollection,
    Iterable[Any],
    Sequence[Any],
    System.Data.Common.DbParameterCollection,
):  # Class
    Count: int  # readonly
    IsFixedSize: bool  # readonly
    IsReadOnly: bool  # readonly
    IsSynchronized: bool  # readonly
    def __getitem__(self, index: int) -> System.Data.SqlServerCe.SqlCeParameter: ...
    def __setitem__(
        self, index: int, value_: System.Data.SqlServerCe.SqlCeParameter
    ) -> None: ...
    def __getitem__(
        self, parameterName: str
    ) -> System.Data.SqlServerCe.SqlCeParameter: ...
    def __setitem__(
        self, parameterName: str, value_: System.Data.SqlServerCe.SqlCeParameter
    ) -> None: ...
    SyncRoot: Any  # readonly

    def GetEnumerator(self) -> Iterator[Any]: ...
    @overload
    def Contains(self, value_: str) -> bool: ...
    @overload
    def Contains(self, value_: Any) -> bool: ...
    def CopyTo(self, array: System.Array, index: int) -> None: ...
    @overload
    def Add(self, value_: Any) -> int: ...
    @overload
    def Add(
        self, value_: System.Data.SqlServerCe.SqlCeParameter
    ) -> System.Data.SqlServerCe.SqlCeParameter: ...
    @overload
    def Add(
        self, parameterName: str, value_: Any
    ) -> System.Data.SqlServerCe.SqlCeParameter: ...
    @overload
    def Add(
        self, parameterName: str, type: System.Data.SqlDbType
    ) -> System.Data.SqlServerCe.SqlCeParameter: ...
    @overload
    def Add(
        self, parameterName: str, type: System.Data.SqlDbType, size: int
    ) -> System.Data.SqlServerCe.SqlCeParameter: ...
    @overload
    def Add(
        self,
        parameterName: str,
        type: System.Data.SqlDbType,
        size: int,
        sourceColumn: str,
    ) -> System.Data.SqlServerCe.SqlCeParameter: ...
    def Clear(self) -> None: ...
    def AddRange(self, values: System.Array) -> None: ...
    @overload
    def IndexOf(self, parameterName: str) -> int: ...
    @overload
    def IndexOf(self, value_: Any) -> int: ...
    def Remove(self, value_: Any) -> None: ...
    def AddWithValue(
        self, parameterName: str, value_: Any
    ) -> System.Data.SqlServerCe.SqlCeParameter: ...
    def Insert(self, index: int, value_: Any) -> None: ...
    @overload
    def RemoveAt(self, index: int) -> None: ...
    @overload
    def RemoveAt(self, parameterName: str) -> None: ...

class SqlCeProviderFactory(
    System.IServiceProvider, System.Data.Common.DbProviderFactory
):  # Class
    def __init__(self) -> None: ...

    Instance: System.Data.SqlServerCe.SqlCeProviderFactory  # static # readonly

    def CreateDataAdapter(self) -> System.Data.Common.DbDataAdapter: ...
    def CreateParameter(self) -> System.Data.Common.DbParameter: ...
    def CreateCommandBuilder(self) -> System.Data.Common.DbCommandBuilder: ...
    def CreateConnection(self) -> System.Data.Common.DbConnection: ...
    def CreateCommand(self) -> System.Data.Common.DbCommand: ...
    def CreateConnectionStringBuilder(
        self,
    ) -> System.Data.Common.DbConnectionStringBuilder: ...

class SqlCeRemoteDataAccess(System.IDisposable):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, internetUrl: str, localConnectionString: str) -> None: ...
    @overload
    def __init__(
        self,
        internetUrl: str,
        internetLogin: str,
        internetPassword: str,
        localConnectionString: str,
    ) -> None: ...

    CompressionLevel: int
    ConnectTimeout: int
    ConnectionManager: bool
    ConnectionRetryTimeout: int
    InternetLogin: str
    InternetPassword: str
    InternetProxyLogin: str
    InternetProxyPassword: str
    InternetProxyServer: str
    InternetUrl: str
    LocalConnectionString: str
    ReceiveTimeout: int
    SendTimeout: int

    @overload
    def Pull(
        self, localTableName: str, sqlSelectString: str, oleDBConnectionString: str
    ) -> None: ...
    @overload
    def Pull(
        self,
        localTableName: str,
        sqlSelectString: str,
        oleDBConnectionString: str,
        trackOption: System.Data.SqlServerCe.RdaTrackOption,
    ) -> None: ...
    @overload
    def Pull(
        self,
        localTableName: str,
        sqlSelectString: str,
        oleDBConnectionString: str,
        trackOption: System.Data.SqlServerCe.RdaTrackOption,
        errorTable: str,
    ) -> None: ...
    @overload
    def Push(self, localTableName: str, oleDBConnectionString: str) -> None: ...
    @overload
    def Push(
        self,
        localTableName: str,
        oleDBConnectionString: str,
        batchOption: System.Data.SqlServerCe.RdaBatchOption,
    ) -> None: ...
    def Dispose(self) -> None: ...
    def SubmitSql(self, sqlString: str, oleDBConnectionString: str) -> None: ...

class SqlCeReplication(System.IDisposable):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        internetUrl: str,
        internetLogin: str,
        internetPassword: str,
        publisher: str,
        publisherDatabase: str,
        publisherLogin: str,
        publisherPassword: str,
        publication: str,
        subscriber: str,
        subscriberConnectionString: str,
    ) -> None: ...
    @overload
    def __init__(
        self,
        internetUrl: str,
        internetLogin: str,
        internetPassword: str,
        publisher: str,
        publisherDatabase: str,
        publication: str,
        subscriber: str,
        subscriberConnectionString: str,
    ) -> None: ...

    CompressionLevel: int
    ConnectTimeout: int
    ConnectionManager: bool
    ConnectionRetryTimeout: int
    Distributor: str
    DistributorAddress: str
    DistributorLogin: str
    DistributorNetwork: System.Data.SqlServerCe.NetworkType
    DistributorPassword: str
    DistributorSecurityMode: System.Data.SqlServerCe.SecurityType
    ExchangeType: System.Data.SqlServerCe.ExchangeType
    HostName: str
    InternetLogin: str
    InternetPassword: str
    InternetProxyLogin: str
    InternetProxyPassword: str
    InternetProxyServer: str
    InternetUrl: str
    LoginTimeout: int
    PostSyncCleanup: int
    ProfileName: str
    Publication: str
    Publisher: str
    PublisherAddress: str
    PublisherChanges: int  # readonly
    PublisherConflicts: int  # readonly
    PublisherDatabase: str
    PublisherLogin: str
    PublisherNetwork: System.Data.SqlServerCe.NetworkType
    PublisherPassword: str
    PublisherSecurityMode: System.Data.SqlServerCe.SecurityType
    QueryTimeout: int
    ReceiveTimeout: int
    SendTimeout: int
    SnapshotTransferType: System.Data.SqlServerCe.SnapshotTransferType
    Subscriber: str
    SubscriberChanges: int  # readonly
    SubscriberConflicts: int  # readonly
    SubscriberConnectionString: str
    Validate: System.Data.SqlServerCe.ValidateType

    @overload
    def BeginSynchronize(
        self, onSyncCompletion: System.AsyncCallback, state: Any
    ) -> System.IAsyncResult: ...
    @overload
    def BeginSynchronize(
        self,
        onSyncCompletion: System.AsyncCallback,
        onStartTableUpload: System.Data.SqlServerCe.OnStartTableUpload,
        onStartTableDownload: System.Data.SqlServerCe.OnStartTableDownload,
        onSynchronization: System.Data.SqlServerCe.OnSynchronization,
        state: Any,
    ) -> System.IAsyncResult: ...
    def CancelSynchronize(self) -> None: ...
    def AddSubscription(self, addOption: System.Data.SqlServerCe.AddOption) -> None: ...
    def LoadProperties(self) -> bool: ...
    def DropSubscription(
        self, dropOption: System.Data.SqlServerCe.DropOption
    ) -> None: ...
    def EndSynchronize(self, ar: System.IAsyncResult) -> None: ...
    def SaveProperties(self) -> None: ...
    def Dispose(self) -> None: ...
    def Synchronize(self) -> None: ...
    def ReinitializeSubscription(self, uploadBeforeReinitialize: bool) -> None: ...

class SqlCeResultSet(
    System.Data.SqlServerCe.SqlCeDataReader,
    System.Data.IDataReader,
    System.Data.IDataRecord,
    System.IDisposable,
    Iterable[Any],
    System.ComponentModel.IListSource,
):  # Class
    def __getitem__(self, index: int) -> Any: ...
    def __getitem__(self, name: str) -> Any: ...
    ResultSetView: System.Data.SqlServerCe.ResultSetView  # readonly
    Scrollable: bool  # readonly
    Sensitivity: System.Data.SqlServerCe.ResultSetSensitivity  # readonly
    Updatable: bool  # readonly

    def GetSqlInt32(self, ordinal: int) -> System.Data.SqlTypes.SqlInt32: ...
    def GetString(self, ordinal: int) -> str: ...
    def ReadFirst(self) -> bool: ...
    def SetChars(
        self,
        ordinal: int,
        dataIndex: int,
        buffer: List[str],
        bufferIndex: int,
        length: int,
    ) -> None: ...
    def SetSqlString(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlString
    ) -> None: ...
    def GetSqlDouble(self, ordinal: int) -> System.Data.SqlTypes.SqlDouble: ...
    def GetDateTime(self, ordinal: int) -> System.DateTime: ...
    def SetSqlBinary(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlBinary
    ) -> None: ...
    def GetSqlBinary(self, ordinal: int) -> System.Data.SqlTypes.SqlBinary: ...
    def SetSqlInt32(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlInt32
    ) -> None: ...
    def GetSqlSingle(self, ordinal: int) -> System.Data.SqlTypes.SqlSingle: ...
    def GetSqlInt64(self, ordinal: int) -> System.Data.SqlTypes.SqlInt64: ...
    def GetChars(
        self,
        ordinal: int,
        dataIndex: int,
        buffer: List[str],
        bufferIndex: int,
        length: int,
    ) -> int: ...
    def SetSqlInt64(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlInt64
    ) -> None: ...
    def ReadPrevious(self) -> bool: ...
    def SetSqlBoolean(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlBoolean
    ) -> None: ...
    def GetSqlDecimal(self, ordinal: int) -> System.Data.SqlTypes.SqlDecimal: ...
    def SetInt32(self, ordinal: int, value_: int) -> None: ...
    def SetSqlMoney(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlMoney
    ) -> None: ...
    def GetInt32(self, ordinal: int) -> int: ...
    def GetByte(self, ordinal: int) -> int: ...
    def GetDecimal(self, ordinal: int) -> System.Decimal: ...
    def GetSqlMoney(self, ordinal: int) -> System.Data.SqlTypes.SqlMoney: ...
    def ReadAbsolute(self, position: int) -> bool: ...
    def SetBoolean(self, ordinal: int, value_: bool) -> None: ...
    def SetByte(self, ordinal: int, value_: int) -> None: ...
    def IsDBNull(self, ordinal: int) -> bool: ...
    def SetDecimal(self, ordinal: int, value_: System.Decimal) -> None: ...
    def SetDouble(self, ordinal: int, value_: float) -> None: ...
    def SetGuid(self, ordinal: int, value_: System.Guid) -> None: ...
    def GetGuid(self, ordinal: int) -> System.Guid: ...
    def GetBoolean(self, ordinal: int) -> bool: ...
    def CreateRecord(self) -> System.Data.SqlServerCe.SqlCeUpdatableRecord: ...
    def GetSqlGuid(self, ordinal: int) -> System.Data.SqlTypes.SqlGuid: ...
    def GetSqlDateTime(self, ordinal: int) -> System.Data.SqlTypes.SqlDateTime: ...
    def SetDateTime(self, ordinal: int, value_: System.DateTime) -> None: ...
    def GetDouble(self, ordinal: int) -> float: ...
    def SetSqlDateTime(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlDateTime
    ) -> None: ...
    def SetSqlDecimal(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlDecimal
    ) -> None: ...
    def SetChar(self, ordinal: int, c: str) -> None: ...
    def SetInt64(self, ordinal: int, value_: int) -> None: ...
    def SetObjectRef(self, ordinal: int, buffer: Any) -> None: ...
    def SetString(self, ordinal: int, value_: str) -> None: ...
    def SetFloat(self, ordinal: int, value_: float) -> None: ...
    def GetSqlMetaData(self, ordinal: int) -> System.Data.SqlServerCe.SqlMetaData: ...
    def GetSqlBoolean(self, ordinal: int) -> System.Data.SqlTypes.SqlBoolean: ...
    def SetDefault(self, ordinal: int) -> None: ...
    def GetInt64(self, ordinal: int) -> int: ...
    def Delete(self) -> None: ...
    def SetSqlSingle(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlSingle
    ) -> None: ...
    def GetSqlByte(self, ordinal: int) -> System.Data.SqlTypes.SqlByte: ...
    def GetValues(self, values: List[Any]) -> int: ...
    def SetInt16(self, ordinal: int, value_: int) -> None: ...
    def GetSqlInt16(self, ordinal: int) -> System.Data.SqlTypes.SqlInt16: ...
    def GetBytes(
        self,
        ordinal: int,
        dataIndex: int,
        buffer: List[int],
        bufferIndex: int,
        length: int,
    ) -> int: ...
    def SetValues(self, values: List[Any]) -> int: ...
    def SetBytes(
        self,
        ordinal: int,
        dataIndex: int,
        buffer: List[int],
        bufferIndex: int,
        length: int,
    ) -> None: ...
    def SetSqlInt16(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlInt16
    ) -> None: ...
    def GetEnumerator(self) -> Iterator[Any]: ...
    def GetInt16(self, ordinal: int) -> int: ...
    def GetFloat(self, ordinal: int) -> float: ...
    def ReadLast(self) -> bool: ...
    def ReadRelative(self, position: int) -> bool: ...
    @overload
    def Insert(self, record: System.Data.SqlServerCe.SqlCeUpdatableRecord) -> None: ...
    @overload
    def Insert(
        self,
        record: System.Data.SqlServerCe.SqlCeUpdatableRecord,
        options: System.Data.SqlServerCe.DbInsertOptions,
    ) -> None: ...
    def SetValue(self, ordinal: int, value_: Any) -> None: ...
    def SetSqlDouble(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlDouble
    ) -> None: ...
    def Update(self) -> None: ...
    def SetSqlGuid(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlGuid
    ) -> None: ...
    def SetSqlByte(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlByte
    ) -> None: ...
    def GetSqlString(self, ordinal: int) -> System.Data.SqlTypes.SqlString: ...
    def GetValue(self, ordinal: int) -> Any: ...
    def IsSetAsDefault(self, ordinal: int) -> bool: ...

class SqlCeRowUpdatedEventArgs(System.Data.Common.RowUpdatedEventArgs):  # Class
    def __init__(
        self,
        dataRow: System.Data.DataRow,
        command: System.Data.IDbCommand,
        statementType: System.Data.StatementType,
        tableMapping: System.Data.Common.DataTableMapping,
    ) -> None: ...

    Command: System.Data.SqlServerCe.SqlCeCommand  # readonly

class SqlCeRowUpdatedEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        e: System.Data.SqlServerCe.SqlCeRowUpdatedEventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(
        self, sender: Any, e: System.Data.SqlServerCe.SqlCeRowUpdatedEventArgs
    ) -> None: ...

class SqlCeRowUpdatingEventArgs(System.Data.Common.RowUpdatingEventArgs):  # Class
    def __init__(
        self,
        dataRow: System.Data.DataRow,
        command: System.Data.IDbCommand,
        statementType: System.Data.StatementType,
        tableMapping: System.Data.Common.DataTableMapping,
    ) -> None: ...

    Command: System.Data.SqlServerCe.SqlCeCommand

class SqlCeRowUpdatingEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        e: System.Data.SqlServerCe.SqlCeRowUpdatingEventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(
        self, sender: Any, e: System.Data.SqlServerCe.SqlCeRowUpdatingEventArgs
    ) -> None: ...

class SqlCeTransaction(
    System.Data.IDbTransaction, System.IDisposable, System.Data.Common.DbTransaction
):  # Class
    CurrentTransactionBsn: int  # readonly
    IsolationLevel: System.Data.IsolationLevel  # readonly
    TrackingContext: System.Guid

    def Dispose(self) -> None: ...
    @overload
    def Commit(self) -> None: ...
    @overload
    def Commit(self, mode: System.Data.SqlServerCe.CommitMode) -> None: ...
    def Rollback(self) -> None: ...

class SqlCeTransactionInProgressException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Data.SqlServerCe.SqlCeException,
):  # Class
    def GetObjectData(
        self,
        info: System.Runtime.Serialization.SerializationInfo,
        context: System.Runtime.Serialization.StreamingContext,
    ) -> None: ...

class SqlCeType:  # Class
    SqlDbType: System.Data.SqlDbType  # readonly

    def ToString(self) -> str: ...

class SqlCeUpdatableRecord(System.Data.IDataRecord):  # Class
    FieldCount: int  # readonly
    HiddenFieldCount: int  # readonly
    def __getitem__(self, ordinal: int) -> Any: ...
    def __setitem__(self, ordinal: int, value_: Any) -> None: ...
    def __getitem__(self, name: str) -> Any: ...
    def __setitem__(self, name: str, value_: Any) -> None: ...
    Updatable: bool  # readonly

    def GetSqlInt32(self, ordinal: int) -> System.Data.SqlTypes.SqlInt32: ...
    def GetString(self, ordinal: int) -> str: ...
    def SetChars(
        self,
        ordinal: int,
        dataIndex: int,
        buffer: List[str],
        bufferIndex: int,
        length: int,
    ) -> None: ...
    def SetSqlString(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlString
    ) -> None: ...
    def GetSqlDouble(self, ordinal: int) -> System.Data.SqlTypes.SqlDouble: ...
    def GetName(self, ordinal: int) -> str: ...
    def GetDateTime(self, ordinal: int) -> System.DateTime: ...
    def SetSqlBinary(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlBinary
    ) -> None: ...
    def GetSqlBinary(self, ordinal: int) -> System.Data.SqlTypes.SqlBinary: ...
    def SetSqlInt32(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlInt32
    ) -> None: ...
    def GetSqlSingle(self, ordinal: int) -> System.Data.SqlTypes.SqlSingle: ...
    def GetSqlInt64(self, ordinal: int) -> System.Data.SqlTypes.SqlInt64: ...
    def GetOrdinal(self, name: str) -> int: ...
    def GetChars(
        self,
        ordinal: int,
        dataIndex: int,
        buffer: List[str],
        bufferIndex: int,
        length: int,
    ) -> int: ...
    def SetSqlInt64(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlInt64
    ) -> None: ...
    def SetSqlBoolean(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlBoolean
    ) -> None: ...
    def GetSqlDecimal(self, ordinal: int) -> System.Data.SqlTypes.SqlDecimal: ...
    def SetInt32(self, ordinal: int, value_: int) -> None: ...
    def SetSqlMoney(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlMoney
    ) -> None: ...
    def GetInt32(self, ordinal: int) -> int: ...
    def GetByte(self, ordinal: int) -> int: ...
    def GetDecimal(self, ordinal: int) -> System.Decimal: ...
    def GetSqlMoney(self, ordinal: int) -> System.Data.SqlTypes.SqlMoney: ...
    def SetBoolean(self, ordinal: int, value_: bool) -> None: ...
    def SetByte(self, ordinal: int, value_: int) -> None: ...
    def SetDecimal(self, ordinal: int, value_: System.Decimal) -> None: ...
    def IsDBNull(self, ordinal: int) -> bool: ...
    def GetSqlCharsRef(self, ordinal: int) -> System.Data.SqlTypes.SqlChars: ...
    def SetDouble(self, ordinal: int, value_: float) -> None: ...
    def SetGuid(self, ordinal: int, value_: System.Guid) -> None: ...
    def GetGuid(self, ordinal: int) -> System.Guid: ...
    def GetBoolean(self, ordinal: int) -> bool: ...
    def GetSqlGuid(self, ordinal: int) -> System.Data.SqlTypes.SqlGuid: ...
    def SetDateTime(self, ordinal: int, value_: System.DateTime) -> None: ...
    def GetSqlDateTime(self, ordinal: int) -> System.Data.SqlTypes.SqlDateTime: ...
    def SetSqlDateTime(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlDateTime
    ) -> None: ...
    def GetDouble(self, ordinal: int) -> float: ...
    def SetSqlDecimal(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlDecimal
    ) -> None: ...
    def SetChar(self, ordinal: int, value_: str) -> None: ...
    def GetSqlBytesRef(self, ordinal: int) -> System.Data.SqlTypes.SqlBytes: ...
    def SetInt64(self, ordinal: int, value_: int) -> None: ...
    def SetObjectRef(self, ordinal: int, value_: Any) -> None: ...
    def SetString(self, ordinal: int, value_: str) -> None: ...
    def SetFloat(self, ordinal: int, value_: float) -> None: ...
    def GetSqlMetaData(self, ordinal: int) -> System.Data.SqlServerCe.SqlMetaData: ...
    def GetSqlBoolean(self, ordinal: int) -> System.Data.SqlTypes.SqlBoolean: ...
    def SetDefault(self, ordinal: int) -> None: ...
    def GetInt64(self, ordinal: int) -> int: ...
    def GetChar(self, ordinal: int) -> str: ...
    def SetSqlSingle(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlSingle
    ) -> None: ...
    def GetSqlByte(self, ordinal: int) -> System.Data.SqlTypes.SqlByte: ...
    def GetValues(self, values: List[Any]) -> int: ...
    def SetInt16(self, ordinal: int, value_: int) -> None: ...
    def GetSqlInt16(self, ordinal: int) -> System.Data.SqlTypes.SqlInt16: ...
    def GetBytes(
        self,
        ordinal: int,
        dataIndex: int,
        buffer: List[int],
        bufferIndex: int,
        length: int,
    ) -> int: ...
    def SetValues(self, values: List[Any]) -> int: ...
    def GetDataTypeName(self, ordinal: int) -> str: ...
    def SetBytes(
        self,
        ordinal: int,
        dataIndex: int,
        buffer: List[int],
        bufferIndex: int,
        length: int,
    ) -> None: ...
    def SetSqlInt16(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlInt16
    ) -> None: ...
    def GetInt16(self, ordinal: int) -> int: ...
    def SetValue(self, ordinal: int, value_: Any) -> None: ...
    def GetFloat(self, ordinal: int) -> float: ...
    def GetFieldType(self, ordinal: int) -> System.Type: ...
    def SetSqlDouble(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlDouble
    ) -> None: ...
    def GetData(self, ordinal: int) -> System.Data.IDataReader: ...
    def SetSqlGuid(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlGuid
    ) -> None: ...
    def SetSqlByte(
        self, ordinal: int, value_: System.Data.SqlTypes.SqlByte
    ) -> None: ...
    def GetSqlString(self, ordinal: int) -> System.Data.SqlTypes.SqlString: ...
    def GetValue(self, ordinal: int) -> Any: ...
    def IsSetAsDefault(self, ordinal: int) -> bool: ...

class SqlMetaData:  # Class
    @overload
    def __init__(self, name: str, dbType: System.Data.SqlDbType) -> None: ...
    @overload
    def __init__(
        self, name: str, dbType: System.Data.SqlDbType, maxLength: int
    ) -> None: ...
    @overload
    def __init__(
        self, name: str, dbType: System.Data.SqlDbType, precision: int, scale: int
    ) -> None: ...
    @overload
    def __init__(
        self,
        name: str,
        dbType: System.Data.SqlDbType,
        maxLength: int,
        locale: int,
        compareOptions: System.Data.SqlTypes.SqlCompareOptions,
    ) -> None: ...
    @overload
    def __init__(
        self,
        name: str,
        dbType: System.Data.SqlDbType,
        maxLength: int,
        precision: int,
        scale: int,
        localeId: int,
        compareOptions: System.Data.SqlTypes.SqlCompareOptions,
        userDefinedType: System.Type,
    ) -> None: ...

    CompareOptions: System.Data.SqlTypes.SqlCompareOptions  # readonly
    DbType: System.Data.DbType  # readonly
    LocaleId: int  # readonly
    Max: int  # static # readonly
    MaxLength: int  # readonly
    Name: str  # readonly
    Precision: int  # readonly
    Scale: int  # readonly
    SqlDbType: System.Data.SqlDbType  # readonly
    TypeName: str  # readonly

    @overload
    def Adjust(self, value_: int) -> int: ...
    @overload
    def Adjust(self, value_: int) -> int: ...
    @overload
    def Adjust(self, value_: int) -> int: ...
    @overload
    def Adjust(self, value_: float) -> float: ...
    @overload
    def Adjust(self, value_: float) -> float: ...
    @overload
    def Adjust(self, value_: str) -> str: ...
    @overload
    def Adjust(self, value_: System.Decimal) -> System.Decimal: ...
    @overload
    def Adjust(self, value_: System.DateTime) -> System.DateTime: ...
    @overload
    def Adjust(self, value_: System.Guid) -> System.Guid: ...
    @overload
    def Adjust(
        self, value_: System.Data.SqlTypes.SqlBoolean
    ) -> System.Data.SqlTypes.SqlBoolean: ...
    @overload
    def Adjust(
        self, value_: System.Data.SqlTypes.SqlByte
    ) -> System.Data.SqlTypes.SqlByte: ...
    @overload
    def Adjust(
        self, value_: System.Data.SqlTypes.SqlInt16
    ) -> System.Data.SqlTypes.SqlInt16: ...
    @overload
    def Adjust(
        self, value_: System.Data.SqlTypes.SqlInt32
    ) -> System.Data.SqlTypes.SqlInt32: ...
    @overload
    def Adjust(
        self, value_: System.Data.SqlTypes.SqlInt64
    ) -> System.Data.SqlTypes.SqlInt64: ...
    @overload
    def Adjust(
        self, value_: System.Data.SqlTypes.SqlSingle
    ) -> System.Data.SqlTypes.SqlSingle: ...
    @overload
    def Adjust(
        self, value_: System.Data.SqlTypes.SqlDouble
    ) -> System.Data.SqlTypes.SqlDouble: ...
    @overload
    def Adjust(
        self, value_: System.Data.SqlTypes.SqlMoney
    ) -> System.Data.SqlTypes.SqlMoney: ...
    @overload
    def Adjust(
        self, value_: System.Data.SqlTypes.SqlDateTime
    ) -> System.Data.SqlTypes.SqlDateTime: ...
    @overload
    def Adjust(
        self, value_: System.Data.SqlTypes.SqlDecimal
    ) -> System.Data.SqlTypes.SqlDecimal: ...
    @overload
    def Adjust(
        self, value_: System.Data.SqlTypes.SqlString
    ) -> System.Data.SqlTypes.SqlString: ...
    @overload
    def Adjust(
        self, value_: System.Data.SqlTypes.SqlBinary
    ) -> System.Data.SqlTypes.SqlBinary: ...
    @overload
    def Adjust(
        self, value_: System.Data.SqlTypes.SqlGuid
    ) -> System.Data.SqlTypes.SqlGuid: ...
    @overload
    def Adjust(
        self, value_: System.Data.SqlTypes.SqlChars
    ) -> System.Data.SqlTypes.SqlChars: ...
    @overload
    def Adjust(
        self, value_: System.Data.SqlTypes.SqlBytes
    ) -> System.Data.SqlTypes.SqlBytes: ...
    @overload
    def Adjust(self, value_: Any) -> Any: ...
    @overload
    def Adjust(self, value_: bool) -> bool: ...
    @overload
    def Adjust(self, value_: int) -> int: ...
    @overload
    def Adjust(self, value_: List[int]) -> List[int]: ...
    @overload
    def Adjust(self, value_: str) -> str: ...
    @overload
    def Adjust(self, value_: List[str]) -> List[str]: ...

class TrackingKeyType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Guid: System.Data.SqlServerCe.TrackingKeyType = ...  # static # readonly
    Max: System.Data.SqlServerCe.TrackingKeyType = ...  # static # readonly
    PrimaryKey: System.Data.SqlServerCe.TrackingKeyType = ...  # static # readonly

class TrackingOptions(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    All: System.Data.SqlServerCe.TrackingOptions = ...  # static # readonly
    Delete: System.Data.SqlServerCe.TrackingOptions = ...  # static # readonly
    Insert: System.Data.SqlServerCe.TrackingOptions = ...  # static # readonly
    Max: System.Data.SqlServerCe.TrackingOptions = ...  # static # readonly
    Update: System.Data.SqlServerCe.TrackingOptions = ...  # static # readonly

class ValidateType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    NoValidation: System.Data.SqlServerCe.ValidateType = ...  # static # readonly
    RowCountOnly: System.Data.SqlServerCe.ValidateType = ...  # static # readonly

class VerifyOption(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Default: System.Data.SqlServerCe.VerifyOption = ...  # static # readonly
    Enhanced: System.Data.SqlServerCe.VerifyOption = ...  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Filters

# Discovered Generic TypeVars:
T = TypeVar("T")
from . import (
    GraphicsRange,
    IFixedGraphics,
    IReportCompliance,
    IReportContext,
    IReportDataProvider,
)

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider

class CalCurveGraphics(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.ICalCurveGraphics,
):  # Class
    def __init__(
        self,
        provider: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.QuantDataProvider,
    ) -> None: ...
    def DrawCalibration(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    def Dispose(self) -> None: ...

class CalCurveWrap(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.ControlWrapBase[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CalCurve
    ]
):  # Class
    def __init__(
        self,
        provider: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.QuantDataProvider,
    ) -> None: ...

class ChromSpecGraphics(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.IChromSpecGraphics,
):  # Class
    def __init__(
        self,
        provider: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.QuantDataProvider,
    ) -> None: ...
    @overload
    def DrawCompoundQualifierPeaks(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawCompoundQualifierPeaks(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...
    def DrawPeakAveragedSpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
    ) -> iTextSharp.text.Image: ...
    def GetReferenceSpectrumRange(
        self, sampleId: int, compoundId: int
    ) -> Optional[GraphicsRange]: ...
    @overload
    def DrawReferenceSpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawReferenceSpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        drawStructure: bool,
    ) -> iTextSharp.text.Image: ...
    def GetAlternativeTargetHitLibrarySpectrumRange(
        self, sampleId: int, compoundId: int
    ) -> Optional[GraphicsRange]: ...
    def DrawCompoundOriginalPeak(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...
    def DrawStructure(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    def GetPeakAveragedSpectrumRange(
        self, sampleId: int, compoundId: int
    ) -> Optional[GraphicsRange]: ...
    @overload
    def DrawCompoundPeak(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawCompoundPeak(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...
    def DrawOriginalQualifierPeak(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        qualifierId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawPeakSpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawPeakSpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
    ) -> iTextSharp.text.Image: ...
    def Dispose(self) -> None: ...
    def DrawAlternativeTargetHitLibrarySpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawQualifierPeak(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        qualifierId: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawQualifierPeak(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        qualifierId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...
    def GetPeakSpectrumRange(
        self, sampleId: int, compoundId: int
    ) -> Optional[GraphicsRange]: ...

class ChromSpecWrap(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.ControlWrapBase[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromSpec
    ]
):  # Class
    def __init__(
        self,
        provider: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.QuantDataProvider,
    ) -> None: ...

class ControlWrapBase(Generic[T]):  # Class
    def __init__(
        self,
        provider: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.QuantDataProvider,
    ) -> None: ...
    def GetControl(self) -> T: ...
    def Release(self) -> None: ...
    def Dispose(self) -> None: ...
    def AddRef(self) -> None: ...

class FixedGraphicsFile(IFixedGraphics, System.IDisposable):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, file: str) -> None: ...
    def Dispose(self) -> None: ...

class ICalCurveGraphics(System.IDisposable):  # Interface
    def DrawCalibration(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...

class IChromSpecGraphics(System.IDisposable):  # Interface
    @overload
    def DrawCompoundQualifierPeaks(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawCompoundQualifierPeaks(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...
    def DrawPeakAveragedSpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
    ) -> iTextSharp.text.Image: ...
    def GetReferenceSpectrumRange(
        self, sampleId: int, compoundId: int
    ) -> Optional[GraphicsRange]: ...
    @overload
    def DrawReferenceSpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawReferenceSpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        drawStructure: bool,
    ) -> iTextSharp.text.Image: ...
    def GetAlternativeTargetHitLibrarySpectrumRange(
        self, sampleId: int, compoundId: int
    ) -> Optional[GraphicsRange]: ...
    def DrawCompoundOriginalPeak(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...
    def DrawStructure(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    def GetPeakAveragedSpectrumRange(
        self, sampleId: int, compoundId: int
    ) -> Optional[GraphicsRange]: ...
    @overload
    def DrawCompoundPeak(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawCompoundPeak(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawPeakSpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawPeakSpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
    ) -> iTextSharp.text.Image: ...
    def DrawAlternativeTargetHitLibrarySpectrum(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawQualifierPeak(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        qualifierId: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawQualifierPeak(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        compoundId: int,
        qualifierId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...
    def GetPeakSpectrumRange(
        self, sampleId: int, compoundId: int
    ) -> Optional[GraphicsRange]: ...

class IDataFilter(object):  # Interface
    FilterString: str  # readonly
    SupportsFilterString: bool  # readonly

    def Match(self, row: System.Data.DataRow) -> bool: ...

class IQuantDataProvider(IReportDataProvider, System.IDisposable):  # Interface
    ApplicationType: str  # readonly
    AuditTrailDataSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet
    )  # readonly
    BatchAttributes: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.BatchAttributes
    )  # readonly
    BatchFileName: str  # readonly
    BatchFolder: str  # readonly
    BatchID: int  # readonly
    BatchPath: str  # readonly
    CompoundFilter: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.IDataFilter
    )
    InstrumentType: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType
    )  # readonly
    IsAuditTrailing: bool  # readonly
    SampleFilter: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.IDataFilter
    )
    _DataNavigator: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.DataNavigator
    )  # readonly

    def GetPeakQualifier(
        self,
        batchId: int,
        sampleId: int,
        compoundId: int,
        qualifierId: int,
        peakId: int,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.PeakQualifierRow
    ): ...
    def GetAllSamples(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.BatchRow
    ]: ...
    def CreateCalCurveGraphics(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.ICalCurveGraphics
    ): ...
    def GetSample(
        self, batchId: int, sampleId: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.BatchRow
    ): ...
    def SelectPeakQualifiers(
        self, filter: str, sort: str
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.PeakQualifierRow
    ]: ...
    def SelectSamples(
        self, filter: str, sort: str
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.BatchRow
    ]: ...
    def SelectPeaks(
        self, filter: str, sort: str
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.PeakRow
    ]: ...
    def SelectCompounds(
        self, filter: str, sort: str
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow
    ]: ...
    def CreateChromSpecGraphics(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.IChromSpecGraphics
    ): ...
    def GetSignals(
        self, batchId: int, sampleId: int
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.SignalRow
    ]: ...
    def CreateSampleGraphics(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.ISampleGraphics
    ): ...
    def GetCompoundChromatogram(self, sampleId: int, compoundId: int) -> Any: ...
    def GetCompound(
        self, batchId: int, sampleId: int, compoundId: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow
    ): ...
    def SelectCalibrations(
        self, filter: str, sort: str
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.CalibrationRow
    ]: ...
    def GetScanTypes(
        self, batchId: int, sampleId: int
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.MSScanType]: ...
    def SelectQualifiers(
        self, filter: str, sort: str
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetQualifierRow
    ]: ...
    def GetTICResponse(
        self, batchId: int, sampleId: int, compoundId: int, istdRT: float
    ) -> float: ...
    def GetQualifier(
        self, batchId: int, sampleId: int, compoundId: int, qualifierId: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetQualifierRow
    ): ...
    def GetPeak(
        self, batchId: int, sampleId: int, compoundId: int, peakId: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.PeakRow
    ): ...
    def GetAllCompounds(
        self, batchId: int, sampleId: int
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow
    ]: ...
    def GetCalibration(
        self, batchId: int, sampleId: int, compoundId: int, levelId: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.CalibrationRow
    ): ...
    def GetSampleChromatogram(
        self, sampleId: int, scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType
    ) -> Any: ...

class IQuantReportScriptTask(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTask,
    System.Xml.Serialization.IXmlSerializable,
    System.IDisposable,
):  # Interface
    BatchFile: str
    BatchPath: str
    CompoundIds: List[int]
    FixedGraphicsFile: str
    GraphicsSettingsFile: str
    InstrumentType: str
    Method: str
    OutputFile: str
    PrinterName: str
    SampleIds: List[int]
    Template: str

class ISampleGraphics(System.IDisposable):  # Interface
    @overload
    def GetChromatogramRange(self, sampleId: int) -> GraphicsRange: ...
    @overload
    def GetChromatogramRange(
        self, sampleId: int, scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType
    ) -> GraphicsRange: ...
    @overload
    def GetChromatogramRange(
        self, sampleId: int, deviceName: str, ordinalNumber: int, signalName: str
    ) -> GraphicsRange: ...
    @overload
    def DrawSampleChromatogram(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawSampleChromatogram(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawSampleChromatogram(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        width: float,
        height: float,
        deviceName: str,
        ordinalNumber: int,
        signalName: str,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawSampleChromatogram(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        width: float,
        height: float,
        deviceName: str,
        ordinalNumber: int,
        signalName: str,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawSampleChromatogram(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        width: float,
        height: float,
        scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawSampleChromatogram(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        width: float,
        height: float,
        scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...

class QuantDataProvider(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.IQuantDataProvider,
    System.IDisposable,
    IReportDataProvider,
):  # Class
    def __init__(
        self,
        presentationState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.PresentationState,
        abort: System.Threading.WaitHandle,
    ) -> None: ...

    ApplicationType: str  # readonly
    AuditTrailDataSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.AuditTrailDataSet
    )  # readonly
    BatchAttributes: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.BatchAttributes
    )  # readonly
    BatchFileName: str  # readonly
    BatchFolder: str  # readonly
    BatchID: int  # readonly
    BatchPath: str  # readonly
    Compliance: IReportCompliance  # readonly
    CompoundFilter: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.IDataFilter
    )
    CurrentVersion: str  # readonly
    FixedGraphics: IFixedGraphics
    InstrumentType: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType
    )  # readonly
    IsAuditTrailing: bool  # readonly
    MethodPath: str
    ReportContext: IReportContext  # readonly
    SampleFilter: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.IDataFilter
    )
    TemplatePath: str
    _DataNavigator: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.DataNavigator
    )  # readonly

    def GetPeakQualifier(
        self,
        batchId: int,
        sampleId: int,
        compoundId: int,
        qualifierId: int,
        peakId: int,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.PeakQualifierRow
    ): ...
    def GetAllSamples(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.BatchRow
    ]: ...
    def FormatNumber(self, columnName: str, value_: float) -> str: ...
    def CreateCalCurveGraphics(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.ICalCurveGraphics
    ): ...
    def IsAttemptingAbort(self) -> bool: ...
    def TranslateEnumValue(
        self, tableName: str, columnName: str, value_: str
    ) -> str: ...
    def Dispose(self) -> None: ...
    def CheckAbortSignal(self) -> None: ...
    def GetSample(
        self, batchId: int, sampleId: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.BatchRow
    ): ...
    def SelectPeakQualifiers(
        self, filter: str, sort: str
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.PeakQualifierRow
    ]: ...
    @staticmethod
    def DrawImage(
        writer: iTextSharp.text.pdf.PdfWriter,
        width: float,
        height: float,
        d: System.Action[Agilent.MassSpectrometry.GUI.Plot.IGraphics],
    ) -> iTextSharp.text.Image: ...
    def SelectSamples(
        self, filter: str, sort: str
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.BatchRow
    ]: ...
    def SelectPeaks(
        self, filter: str, sort: str
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.PeakRow
    ]: ...
    def GetNumberFormat(self, columnName: str) -> str: ...
    def FormatDateTime(self, columnName: str, value_: System.DateTime) -> str: ...
    def ProgressMessage(self, pageNumber: int, message: str) -> None: ...
    def SelectCompounds(
        self, filter: str, sort: str
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow
    ]: ...
    def CreateChromSpecGraphics(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.IChromSpecGraphics
    ): ...
    def GetSignals(
        self, batchId: int, sampleId: int
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.SignalRow
    ]: ...
    def CreateSampleGraphics(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.ISampleGraphics
    ): ...
    def GetCompoundChromatogram(self, sampleId: int, compoundId: int) -> Any: ...
    def GetCompound(
        self, batchId: int, sampleId: int, compoundId: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow
    ): ...
    def SelectCalibrations(
        self, filter: str, sort: str
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.CalibrationRow
    ]: ...
    def GetScanTypes(
        self, batchId: int, sampleId: int
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.MSScanType]: ...
    def SelectQualifiers(
        self, filter: str, sort: str
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetQualifierRow
    ]: ...
    def GetPeak(
        self, batchId: int, sampleId: int, compoundId: int, peakId: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.PeakRow
    ): ...
    def GetQualifier(
        self, batchId: int, sampleId: int, compoundId: int, qualifierId: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetQualifierRow
    ): ...
    def GetAllCompounds(
        self, batchId: int, sampleId: int
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow
    ]: ...
    def GetTICResponse(
        self, batchId: int, sampleId: int, compoundId: int, istdRT: float
    ) -> float: ...
    def GetCalibration(
        self, batchId: int, sampleId: int, compoundId: int, levelId: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.CalibrationRow
    ): ...
    def GetSampleChromatogram(
        self, sampleId: int, scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType
    ) -> Any: ...

class QuantReportScriptTask(
    System.Xml.Serialization.IXmlSerializable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTask,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.IQuantReportScriptTask,
):  # Class
    def __init__(self) -> None: ...

    BatchFile: str
    BatchPath: str
    CompoundIds: List[int]
    Context: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QueuedTask.IQueuedTaskContext
    )
    FixedGraphicsFile: str
    GraphicsSettingsFile: str
    InstrumentType: str
    Method: str
    OutputFile: str
    PrinterName: str
    SampleIds: List[int]
    Template: str

    def Dispose(self) -> None: ...

class SampleDataWrap(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.ControlWrapBase[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.SampleData.SampleDataControl
    ]
):  # Class
    def __init__(
        self,
        provider: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.QuantDataProvider,
    ) -> None: ...

class SampleGraphics(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.ISampleGraphics,
):  # Class
    def __init__(
        self,
        provider: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.QuantDataProvider.QuantDataProvider,
    ) -> None: ...
    @overload
    def GetChromatogramRange(self, sampleId: int) -> GraphicsRange: ...
    @overload
    def GetChromatogramRange(
        self, sampleId: int, scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType
    ) -> GraphicsRange: ...
    @overload
    def GetChromatogramRange(
        self, sampleId: int, deviceName: str, ordinalNumber: int, signalName: str
    ) -> GraphicsRange: ...
    def Dispose(self) -> None: ...
    @overload
    def DrawSampleChromatogram(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        width: float,
        height: float,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawSampleChromatogram(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        width: float,
        height: float,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawSampleChromatogram(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        width: float,
        height: float,
        scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawSampleChromatogram(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        width: float,
        height: float,
        scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawSampleChromatogram(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        width: float,
        height: float,
        deviceName: str,
        ordinalNumber: int,
        signalName: str,
    ) -> iTextSharp.text.Image: ...
    @overload
    def DrawSampleChromatogram(
        self,
        writer: iTextSharp.text.pdf.PdfWriter,
        sampleId: int,
        width: float,
        height: float,
        deviceName: str,
        ordinalNumber: int,
        signalName: str,
        minx: Optional[float],
        maxx: Optional[float],
        miny: Optional[float],
        maxy: Optional[float],
    ) -> iTextSharp.text.Image: ...

class SignalRow:  # Class
    def __init__(self) -> None: ...

    BatchID: int
    DeviceName: str  # readonly
    IsMS: bool  # readonly
    OrdinalNumber: int  # readonly
    SampleID: int
    SignalName: str  # readonly

    def ToString(self) -> str: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import INumericCustomFormat

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.NumericFormat

class CustomFormatBase:  # Class
    ...

class SignificantFiguresFormat(
    System.IFormatProvider,
    INumericCustomFormat,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.NumericFormat.CustomFormatBase,
    System.ICustomFormatter,
):  # Class
    @overload
    def __init__(self, digits: int) -> None: ...
    @overload
    def __init__(self, digits: int, provider: System.IFormatProvider) -> None: ...

    Digits: int
    FormatProvider: System.IFormatProvider  # readonly
    FormatString: str  # readonly

    def GetFormat(self, formatType: System.Type) -> Any: ...
    def Format(
        self, format: str, arg: Any, formatProvider: System.IFormatProvider
    ) -> str: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.ErrorWindow

class App(
    System.Windows.Application,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def Main() -> None: ...

class CommandLine:  # Class
    def __init__(self) -> None: ...

    ApplicationName: str
    DetailsFile: str
    Logfile: str

class ErrorWindowModel(System.Windows.DependencyObject):  # Class
    def __init__(self) -> None: ...

    ApplicationNameProperty: System.Windows.DependencyProperty  # static
    DetailsFileProperty: System.Windows.DependencyProperty  # static
    DetailsProperty: System.Windows.DependencyProperty  # static
    DetailsVisibilityProperty: System.Windows.DependencyProperty  # static
    LogFileProperty: System.Windows.DependencyProperty  # static
    MessageProperty: System.Windows.DependencyProperty  # static
    ShowDetailsProperty: System.Windows.DependencyProperty  # static

    ApplicationName: str
    CommandCopyDetails: System.Windows.Input.ICommand  # readonly
    CommandShowLogfile: System.Windows.Input.ICommand  # readonly
    Details: str
    DetailsFile: str
    DetailsVisibility: System.Windows.Visibility
    LogFile: str
    Message: str
    ShowDetails: bool

    @staticmethod
    def ShowErrorWindow(
        appName: str,
        assembly: System.Reflection.Assembly,
        exception: System.Exception,
        logFile: str,
    ) -> None: ...

class MainWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...
